#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-manipulate
version:              0.3.1.0
visibility:           public
id:                   text-manipulate-0.3.1.0-BjRaLKvcXmp8dxirXE9PUB
key:                  text-manipulate-0.3.1.0-BjRaLKvcXmp8dxirXE9PUB
license:              MPL-2.0
copyright:            Copyright (c) 2014-2022 Brendan Hay
maintainer:           Brendan Hay <brendan.g.hay@gmail.com>
author:               Brendan Hay
homepage:             https://github.com/brendanhay/text-manipulate
synopsis:
    Case conversion, word boundary manipulation, and textual subjugation.

description:
    Manipulate identifiers and structurally non-complex pieces
    of text by delimiting word boundaries via a combination of whitespace,
    control-characters, and case-sensitivity.

    Has support for common idioms like casing of programmatic variable names,
    taking, dropping, and splitting by word, and modifying the first character
    of a piece of text.

category:             Data, Text
abi:                  3993eededd6173b798fc48c9c114b112
exposed:              True
exposed-modules:      Data.Text.Lazy.Manipulate Data.Text.Manipulate
hidden-modules:
    Data.Text.Manipulate.Internal.Fusion
    Data.Text.Manipulate.Internal.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/text-manipulate-0.3.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/text-manipulate-0.3.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/text-manipulate-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-manipulate
hs-libraries:         HStext-manipulate-0.3.1.0-BjRaLKvcXmp8dxirXE9PUB
depends:              base-4.18.2.1 text-2.0.2
haddock-interfaces:
    /usr/share/doc/haskell-text-manipulate/html/text-manipulate.haddock

haddock-html:         /usr/share/doc/haskell-text-manipulate/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

